@@ -1,6 +1,16 @@
 from pydantic import BaseModel
 
-from acp_sdk.models.models import Agent, AgentName, AwaitResume, Event, Message, Run, RunMode, SessionId
+from acp_sdk.models.models import (
+    AgentManifest,
+    AgentName,
+    AwaitResume,
+    Event,
+    Message,
+    Run,
+    RunMode,
+    Session,
+    SessionId,
+)
 
 
 class PingResponse(BaseModel):
@@ -8,16 +18,17 @@ class PingResponse(BaseModel):
 
 
 class AgentsListResponse(BaseModel):
-    agents: list[Agent]
+    agents: list[AgentManifest]
 
 
-class AgentReadResponse(Agent):
+class AgentReadResponse(AgentManifest):
     pass
 
 
 class RunCreateRequest(BaseModel):
     agent_name: AgentName
     session_id: SessionId | None = None
+    session: Session | None = None
     input: list[Message]
     mode: RunMode = RunMode.SYNC
 
@@ -45,3 +56,7 @@ class RunCancelResponse(Run):
 
 class RunEventsListResponse(BaseModel):
     events: list[Event]
+
+
+class SessionReadResponse(Session):
+    pass
