@@ -9,7 +9,7 @@ from pydantic import BaseModel
 from acp_sdk.models import RunStatus
 from acp_sdk.server.executor import RunData
 from acp_sdk.server.logging import logger
-from acp_sdk.server.store.store import Store
+from acp_sdk.server.store import Store
 
 
 def encode_sse(model: BaseModel) -> str:
